Structs
- Handles
- An iterator that yields all handles in a
SparseHandleMap. - Iter
- An iterator that yields all handles and value refrences in a
SparseHandleMap. - IterMut
- An iterator that yields all handles and mutable value refrences in a
SparseHandleMap. - Sparse
Handle Map - Values
- An iterator that yields all value refrences in a
SparseHandleMap. - Values
Mut - An iterator that yields all mutable value refrences in a
SparseHandleMap.